@@ -1,10 +1,10 @@
 package Net::DNS::RR::L64;
 
 #
-# $Id: L64.pm 1339 2015-04-16 13:01:17Z willem $
+# $Id: L64.pm 1382 2015-08-26 20:39:33Z willem $
 #
 use vars qw($VERSION);
-$VERSION = (qw$LastChangedRevision: 1339 $)[1];
+$VERSION = (qw$LastChangedRevision: 1382 $)[1];
 
 
 use strict;
@@ -20,7 +20,7 @@ Net::DNS::RR::L64 - DNS L64 resource record
 use integer;
 
 
-sub decode_rdata {			## decode rdata from wire-format octet string
+sub _decode_rdata {			## decode rdata from wire-format octet string
 	my $self = shift;
 	my ( $data, $offset ) = @_;
 
@@ -28,23 +28,23 @@ sub decode_rdata {			## decode rdata from wire-format octet string
 }
 
 
-sub encode_rdata {			## encode rdata as wire-format octet string
+sub _encode_rdata {			## encode rdata as wire-format octet string
 	my $self = shift;
 
-	return '' unless $self->{locator64} && length $self->{locator64};
+	return '' unless $self->{locator64};
 	pack 'n a8', $self->{preference}, $self->{locator64};
 }
 
 
-sub format_rdata {			## format rdata portion of RR string.
+sub _format_rdata {			## format rdata portion of RR string.
 	my $self = shift;
 
-	return '' unless $self->{locator64} && length $self->{locator64};
+	return '' unless $self->{locator64};
 	return join ' ', $self->preference, $self->locator64;
 }
 
 
-sub parse_rdata {			## populate RR from rdata in argument list
+sub _parse_rdata {			## populate RR from rdata in argument list
 	my $self = shift;
 
 	$self->preference(shift);
@@ -56,7 +56,7 @@ sub preference {
 	my $self = shift;
 
 	$self->{preference} = 0 + shift if scalar @_;
-	return $self->{preference} || 0;
+	$self->{preference} || 0;
 }
 
 
@@ -66,17 +66,18 @@ sub locator64 {
 
 	$self->{locator64} = pack 'n4', map hex($_), split /:/, $prfx if defined $prfx;
 
-	sprintf '%x:%x:%x:%x', unpack 'n4', $self->{locator64} if defined wantarray;
+	sprintf '%x:%x:%x:%x', unpack 'n4', $self->{locator64}
+			if defined wantarray && $self->{locator64};
 }
 
 
-__PACKAGE__->set_rrsort_func(		## sort RRs in numerically ascending order.
-	'preference',
-	sub { $Net::DNS::a->{'preference'} <=> $Net::DNS::b->{'preference'} }
+my $function = sub {			## sort RRs in numerically ascending order.
+	$Net::DNS::a->{'preference'} <=> $Net::DNS::b->{'preference'};
+};
 
-	);
+__PACKAGE__->set_rrsort_func( 'preference', $function );
 
-__PACKAGE__->set_rrsort_func( 'default_sort', __PACKAGE__->get_rrsort_func('preference') );
+__PACKAGE__->set_rrsort_func( 'default_sort', $function );
 
 
 1;
