@@ -1,10 +1,10 @@
 package Net::DNS::RR::TLSA;
 
 #
-# $Id: TLSA.pm 1362 2015-06-23 08:47:14Z willem $
+# $Id: TLSA.pm 1382 2015-08-26 20:39:33Z willem $
 #
 use vars qw($VERSION);
-$VERSION = (qw$LastChangedRevision: 1362 $)[1];
+$VERSION = (qw$LastChangedRevision: 1382 $)[1];
 
 
 use strict;
@@ -19,10 +19,10 @@ Net::DNS::RR::TLSA - DNS TLSA resource record
 
 use integer;
 
-use constant BABBLE => ref( eval { require Digest::BubbleBabble; \1; } );
+use constant BABBLE => defined eval { require Digest::BubbleBabble; };
 
 
-sub decode_rdata {			## decode rdata from wire-format octet string
+sub _decode_rdata {			## decode rdata from wire-format octet string
 	my $self = shift;
 	my ( $data, $offset ) = @_;
 
@@ -34,7 +34,7 @@ sub decode_rdata {			## decode rdata from wire-format octet string
 }
 
 
-sub encode_rdata {			## encode rdata as wire-format octet string
+sub _encode_rdata {			## encode rdata as wire-format octet string
 	my $self = shift;
 
 	return '' unless defined $self->{certbin};
@@ -42,7 +42,7 @@ sub encode_rdata {			## encode rdata as wire-format octet string
 }
 
 
-sub format_rdata {			## format rdata portion of RR string.
+sub _format_rdata {			## format rdata portion of RR string.
 	my $self = shift;
 
 	return '' unless defined $self->{certbin};
@@ -52,7 +52,7 @@ sub format_rdata {			## format rdata portion of RR string.
 }
 
 
-sub parse_rdata {			## populate RR from rdata in argument list
+sub _parse_rdata {			## populate RR from rdata in argument list
 	my $self = shift;
 
 	$self->usage(shift);
@@ -161,6 +161,9 @@ presented by the server will be matched against the association data.
 8-bit integer value which specifies how the certificate association
 is presented.
 
+=head2 certificate
+
+
 =head2 cert
 
     $cert = $rr->cert;
